# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django import forms
from django.contrib.auth.forms import (
    AuthenticationForm,
    PasswordChangeForm,
    PasswordResetForm,
    SetPasswordForm,
)
from django.utils.translation import ugettext_lazy as _

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import (
    ButtonHolder,
    Column,
    Fieldset,
    Layout,
    Row,
    Submit,
)

from django_countries import countries
from django_countries.fields import LazyTypedChoiceField

from registration.forms import RegistrationFormUniqueEmail


class FormHelperMixin(object):
    """
    Adds a simple form helper that will only display the input fields
    from the form and the csrf.

    <form/> tag and submit button is at your charge in the templates, fields
    are automatically selected from the form and csrf is inserted.
    """

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_tag = False
        super(FormHelperMixin, self).__init__(*args, **kwargs)


class CustomAuthenticationForm(FormHelperMixin, AuthenticationForm):
    pass


class CustomPasswordChangeForm(FormHelperMixin, PasswordChangeForm):
    pass


class CustomPasswordResetForm(FormHelperMixin, PasswordResetForm):
    pass


class CustomSetPasswordForm(FormHelperMixin, SetPasswordForm):
    pass


class CustomRegistrationForm(RegistrationFormUniqueEmail):
    first_name = forms.CharField(label=_('First Name'), required=False)
    last_name = forms.CharField(label=_('Last Name'))
    company = forms.CharField(label=_('Company'))
    function = forms.CharField(label=_('Function'))
    address = forms.CharField(label=_('Address'),
                              required=False,
                              widget=forms.Textarea(attrs={'rows': 3}))
    zip_code = forms.CharField(label=_('Zip code'), required=False)
    city = forms.CharField(label=_('City'), required=False)
    country = LazyTypedChoiceField(label=_('Country'), choices=countries)
    phone = forms.CharField(label=_('Professional phone number'),
                            required=False)

    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_action = '.'
        self.helper.layout = Layout(
            Fieldset(
                _('User'),
                Row(
                    Column('username', css_class='six'),
                    Column(
                        Row(
                            Column('password1', css_class='six unpadded'),
                            Column('password2', css_class='six unpadded'),
                        ),
                        css_class='six'
                    ),
                ),
            ),
            Fieldset(
                _('Company'),
                Row(
                    Column('company', css_class='six'),
                    Column('function', css_class='six'),
                ),
            ),
            Fieldset(
                _('Personal details'),
                Row(
                    Column(
                        Row(
                            Column('first_name', css_class='six unpadded'),
                            Column('last_name', css_class='six unpadded'),
                        ),
                        css_class='six'
                    ),
                    Column('email', css_class='six'),
                ),
                Row(
                    Column('address', css_class='six'),
                    Column(
                        Row(
                            Column('city', css_class='eight unpadded'),
                            Column('postal_code', css_class='four unpadded'),
                            Column('country', css_class='six unpadded'),
                            Column('phone', css_class='six unpadded'),
                        ),
                        css_class='six'
                    ),
                ),
            ),
            Row(
                Column(
                    ButtonHolder(Submit('submit', _('Submit')),
                                 css_class="text-right"),
                    css_class='twelve'
                ),
            )
        )

        super(CustomRegistrationForm, self).__init__(*args, **kwargs)
