# coding: utf-8

import pytest

from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
from django.test import RequestFactory, TestCase

from registration.models import RegistrationProfile

from ..views import (
    CustomActivationView,
    CustomRegistrationView,
    RegistrationClosedView,
    RegistrationCompleteView,
    RegistrationActivationCompleteView,
)


class TestTemplateView(TestCase):
    @classmethod
    def setUpTestData(cls):
        cls.factory = RequestFactory()

    def test_template_registration_closed(self):
        with self.assertTemplateUsed('registration/registration_closed.html'):
            request = self.factory.get(reverse('registration_closed'))
            resp = RegistrationClosedView.as_view()(request)
            resp.render()

    def test_template_registration_complete(self):
        with self.assertTemplateUsed('registration/registration_complete.html'):
            request = self.factory.get(reverse('registration_complete'))
            resp = RegistrationCompleteView.as_view()(request)
            resp.render()

    def test_template_registration_activate(self):
        with self.assertTemplateUsed('registration/activation_complete.html'):
            request = self.factory.get(reverse('registration_complete'))
            resp = RegistrationActivationCompleteView.as_view()(request)
            resp.render()


@pytest.mark.django_db
def test_activation_view(mocker):
    user_info = {
        User.USERNAME_FIELD: 'alice',
        'password': 'swordfish',
        'email': 'alice@example.com'
    }

    new_user = User.objects.create_user(**user_info)
    profile = RegistrationProfile.objects.create_profile(new_user)

    mock = mocker.patch('accounts.views.send_confirmation_email')
    assert not mock.called

    factory = RequestFactory()
    request = factory.get(reverse(
        'registration_activate',
        kwargs={"activation_key": profile.activation_key}))
    request.user = new_user
    CustomActivationView.as_view()(
        request, profile.activation_key)
    assert mock.called


@pytest.mark.django_db
def test_registration_view(mocker):
    data = {
        User.USERNAME_FIELD: 'alice',
        'password1': 'swordfish',
        'password2': 'swordfish',
        'email': 'alice@example.com',
        "first_name": "first",
        "last_name": "last",
        "company": "foo company",
        "function": "foo function",
        "address": "foo address",
        "zip_code": "foo000",
        "country": "FR",
        "phone": "1478520695",
    }

    mock = mocker.patch('accounts.views.send_activation_email')
    mock2 = mocker.patch('accounts.views.send_activation_pending_email')
    assert not mock.called and not mock2.called

    factory = RequestFactory()
    request = factory.post(reverse('registration_register'))
    request.POST = data

    CustomRegistrationView.as_view()(request)
    assert mock.called and mock2.called
