# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.contrib.auth.views import (
    login,
    password_change,
    password_reset,
    password_reset_confirm,
)
from django.contrib.sites.models import Site
from django.views.generic import TemplateView

from registration.backends.default.views import (
    ActivationView,
    RegistrationView,
)

from .forms import (
    CustomAuthenticationForm,
    CustomPasswordChangeForm,
    CustomPasswordResetForm,
    CustomRegistrationForm,
    CustomSetPasswordForm,
)
from .mails import (
    send_activation_email,
    send_activation_pending_email,
    send_confirmation_email,
)
from .models import UserProfile


def custom_login(*args, **kwargs):
    return login(*args, authentication_form=CustomAuthenticationForm, **kwargs)


def custom_password_change(*args, **kwargs):
    return password_change(*args,
                           password_change_form=CustomPasswordChangeForm,
                           **kwargs)


def custom_password_reset(*args, **kwargs):
    return password_reset(*args,
                          password_reset_form=CustomPasswordResetForm,
                          **kwargs)


def custom_password_reset_confirm(*args, **kwargs):
    return password_reset_confirm(*args,
                                  set_password_form=CustomSetPasswordForm,
                                  **kwargs)


class CustomRegistrationView(RegistrationView):
    """
    Overload Registration class to fill additional user profile datas and
    send activation email to admins
    """
    form_class = CustomRegistrationForm
    SEND_ACTIVATION_EMAIL = False

    def register(self, form):
        # Note: 'register' ancestor method will send 'user_registered'
        # signal, but at this point all datas are not filled yet.
        # So you better not rely on this signal.
        new_user = super(CustomRegistrationView, self).register(form)

        site = Site.objects.get_current()

        new_user.first_name = form.cleaned_data['first_name']
        new_user.last_name = form.cleaned_data['last_name']
        new_user.save()

        # Fill profile
        user_profile = UserProfile.objects.create(
            user=new_user,
            company=form.cleaned_data['company'],
            function=form.cleaned_data['function'],
            address=form.cleaned_data['address'],
            zip_code=form.cleaned_data['zip_code'],
            city=form.cleaned_data['city'],
            country=form.cleaned_data['country'],
            phone=form.cleaned_data['phone'],
        )

        # Send emails to user and admin(s)
        send_activation_email(new_user, site, user_profile)
        send_activation_pending_email(new_user, site, user_profile)

        return new_user


class CustomActivationView(ActivationView):
    """
    Overload Activation view to send confirmation email when succeeded
    """
    def activate(self, request, activation_key):
        user = super(CustomActivationView, self).activate(
            request, activation_key=activation_key)

        if user:
            send_confirmation_email(user, Site.objects.get_current())

        return user


class RegistrationClosedView(TemplateView):
    template_name = "registration/registration_closed.html"


class RegistrationCompleteView(TemplateView):
    template_name = "registration/registration_complete.html"


class RegistrationActivationCompleteView(TemplateView):
    template_name = "registration/activation_complete.html"
